using ValidatorsLibrary;

namespace ValidatorTests;

public class NonBlankStringValidatorTests
{
    [Fact]
    public void Valid_SimpleText()
    {
        var validator = new NonBlankStringValidator();
        Assert.Empty(validator.Validate("text"));
    }

    [Fact]
    public void Valid_SimpleTextWithSpaces()
    {
        var validator = new NonBlankStringValidator();
        Assert.Empty(validator.Validate("text more text"));
    }

    [Fact]
    public void Valid_SpacesAtBeginning()
    {
        var validator = new NonBlankStringValidator();
        Assert.Empty(validator.Validate("   text"));
    }

    [Fact]
    public void Valid_SpacesAtEnd()
    {
        var validator = new NonBlankStringValidator();
        Assert.Empty(validator.Validate("text    "));
    }

    [Fact]
    public void Invalid_EmptyString()
    {
        var validator = new NonBlankStringValidator();
        Assert.NotEmpty(validator.Validate(""));
    }

    [Fact]
    public void Invalid_JustSpaces()
    {
        var validator = new NonBlankStringValidator();
        Assert.NotEmpty(validator.Validate("    "));
    }

    [Fact]
    public void Invalid_JustTabs()
    {
        var validator = new NonBlankStringValidator();
        Assert.NotEmpty(validator.Validate("\t\t\t"));
    }

    [Fact]
    public void Invalid_JustNewlines()
    {
        var validator = new NonBlankStringValidator();
        Assert.NotEmpty(validator.Validate("\n\n\n"));
    }

    [Fact]
    public void Invalid_MixtureOfAll()
    {
        var validator = new NonBlankStringValidator();
        Assert.NotEmpty(validator.Validate("  \t  \n\t  \n "));
    }
}