﻿namespace ValidatorsLibrary;

public class RangeValidator<T> : IValidator<T> where T : IComparable<T>
{
    public required T Min { get; init; }
    public required T Max { get; init; }

    public IEnumerable<ValidationError> Validate(T value)
    {
        if (value.CompareTo(Min) < 0)
        {
            return [new ValidationError($"{value} is less than minimum {Min}.")];
        }
        if (value.CompareTo(Max) > 0)
        {
            return [new ValidationError($"{value} is greater than maximum {Max}.")];
        }
        return Array.Empty<ValidationError>();
    }
}
