﻿#define BETTER_VALIDATE

namespace ValidatorsLibrary;

public interface IValidator<in T>
{
    IEnumerable<ValidationError> Validate(T value);
}

public abstract class Validator<T> : IValidator<T>
{
    public abstract IEnumerable<ValidationError> Validate(T value);

#if !BETTER_VALIDATE
    protected IEnumerable<ValidationError> Validate<TValue>(TValue value, params IValidator<TValue>[] validators)
    {
        var allErrors = new List<ValidationError>();
        foreach (var validator in validators)
        {
            allErrors.AddRange(validator.Validate(value));
        }
        return allErrors;
    }
#else
	protected IEnumerable<ValidationError> Validate<TValue>(
		TValue value,
		IValidator<TValue> firstValidator,
		params IValidator<TValue>[] validators
	) {
		var allErrors = new List<ValidationError>();

		allErrors.AddRange(firstValidator.Validate(value));

		foreach (var validator in validators) {
			allErrors.AddRange(validator.Validate(value));
		}
		return allErrors;
	}
#endif

    #region Advanced scenario syntax
    protected RangeValidator<TValue> InRange<TValue>(TValue min, TValue max) where TValue : IComparable<TValue>
    {
        return new RangeValidator<TValue> { Min = min, Max = max };
    }

    protected NonBlankStringValidator IsNonBlankString() => new NonBlankStringValidator();

    protected StringLengthValidator IsStringWithLength(IValidator<int> lengthValidator)
    {
        return new StringLengthValidator(lengthValidator);
    }

    protected NotNullValidator IsNonNull() => new NotNullValidator();
    #endregion
}
